@@ -1,4 +1,4 @@
-# Copyright 2001-2015, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Criterion;
 use strict;
 use warnings;
 
-our $VERSION = '1.21'; # VERSION
+our $VERSION = '1.30'; # VERSION
 
 use Devel::Cover::Statement;
 use Devel::Cover::Branch;
@@ -24,17 +24,18 @@ use Devel::Cover::Subroutine;
 use Devel::Cover::Time;
 use Devel::Cover::Pod;
 
-sub coverage    { $_[0][0] }
-sub information { $_[0][1] }
+sub coverage    { $_[0][0]                                        }
+sub information { $_[0][1]                                        }
 
-sub uncoverable { "n/a" }
-sub covered     { "n/a" }
-sub total       { "n/a" }
-sub percentage  { "n/a" }
-sub error       { "n/a" }
-sub text        { "n/a" }
-sub values      { [ $_[0]->covered ] }
-sub criterion   { require Carp; Carp::confess("criterion() must be overridden") }
+sub uncoverable { "n/a"                                           }
+sub covered     { "n/a"                                           }
+sub total       { "n/a"                                           }
+sub percentage  { "n/a"                                           }
+sub error       { "n/a"                                           }
+sub text        { "n/a"                                           }
+sub values      { [ $_[0]->covered ]                              }
+sub criterion   { require Carp;
+                  Carp::confess("criterion() must be overridden") }
 
 sub calculate_percentage {
     my $class = shift;
@@ -76,7 +77,7 @@ Devel::Cover::Criterion - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.21
+version 1.30
 
 =head1 SYNOPSIS
 
@@ -100,7 +101,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2015, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
